@@ -32,6 +32,7 @@ from asyncpg.pool import create_pool
 from ajsonapi.events import Event
 from ajsonapi.exceptions import ErrorsException
 from ajsonapi.init import init
+from ajsonapi.logging import log
 from ajsonapi.requests import (
     parse_collection_document_query,
     parse_collection_query,
@@ -326,9 +327,8 @@ class Application:
                 # Eventually: allow clients to register/deregister individual
                 # events they are interested in.
             elif msg.type == WSMsgType.ERROR:
-                print('websocket connection closed with exception',
-                      ws.exception())
-        print('websocket connection closed')
+                log.debug('websocket connection closed with exception',
+                          ws.exception())
         self.ws_list.remove(ws)
         return ws
 
