@@ -32,7 +32,7 @@ class Attribute(Field):
 
     def __init__(self, type_):
         self.type_ = type_
-        self.name = None  # Overridden in JSON_API.__init_subclass__
+        self.name = ''  # Overridden in JSON_API.__init_subclass__
 
     def filter_condition(self, values):
         sql_values = [
