@@ -65,8 +65,8 @@ class Document:
             if type_name != expected_type_name:
                 errors.append(
                     DocumentDataInvalidTypeError(f'/data/type/{type_name}'))
-        except TypeError:
-            raise ErrorsException([DocumentDataMalformedError()])
+        except TypeError as exc:
+            raise ErrorsException([DocumentDataMalformedError()]) from exc
         except KeyError:
             errors.append(DocumentDataMissingTypeError('/data'))
 
@@ -296,12 +296,12 @@ class ResourceIdentifierObjectsDocument(Document):
             if not obj_type_names <= {expected_type_name}:
                 raise TypeNameError()
             self.ids = [IdValue(obj['id']) for obj in self.data]
-        except (KeyError, ValueError, TypeNameError):
+        except (KeyError, ValueError, TypeNameError) as exc:
             errors = []
             for index, roi in enumerate(self.data):
                 parse_roi_type(roi, index, expected_type_name, errors)
                 parse_roi_id(roi, index, errors)
-            raise ErrorsException(errors)
+            raise ErrorsException(errors) from exc
 
 
 async def parse_request_document_data(request):
@@ -320,10 +320,10 @@ async def parse_request_document_data(request):
 
     try:
         document = await request.json()
-    except JSONDecodeError:
-        raise ErrorsException([DocumentNotJsonError()])
+    except JSONDecodeError as exc:
+        raise ErrorsException([DocumentNotJsonError()]) from exc
     try:
         data = document['data']
-    except KeyError:
-        raise ErrorsException([DocumentDataMissingError()])
+    except KeyError as exc:
+        raise ErrorsException([DocumentDataMissingError()]) from exc
     return data
