@@ -717,3 +717,23 @@ class DeleteObjectRemotelyRelatedError(Error):
             },
             'title': 'Cannot delete a remotely related resource object.',
         }
+
+
+class AuthorizationError(Error):
+    """This error indicates that the request did not contain a proper
+    authentication bearer token.
+    """
+
+    # pylint: disable=too-few-public-methods
+
+    status = 401
+
+    def __init__(self, detail):
+        self.detail = detail
+
+    def to_error(self):
+        return {
+            'status': '401',
+            'title': 'Unauthorized',
+            'detail': self.detail,
+        }
