@@ -34,6 +34,7 @@ from ajsonapi.relationships import (
     Relationship,
 )
 from ajsonapi.toposort import CircularDependencyError, toposort
+from ajsonapi.types import Int64
 from ajsonapi.uri.collection import Collection
 
 
@@ -171,13 +172,22 @@ class Table:
                 columns_now.append(col)
         table_fields = ',\n   '.join(
             chain((col.sql() for col in cls.columns),
-                  (col.sql_constraints()
-                   for col in cls.constraints
-                   if col in columns_now)))
-        stmt_table = (f'CREATE TABLE IF NOT EXISTS {cls.name} (\n   '
-                      f'{table_fields}\n);')
-        stmts_fk = list(f'ALTER TABLE {cls.name} ADD {col.sql_constraints()}'
-                        for col in columns_later)
+                  chain.from_iterable(col.sql_constraints()
+                                      for col in cls.constraints
+                                      if col in columns_now)))
+        # pylint: disable=no-member
+        if hasattr(cls, 'id') and cls.id.type_ == Int64:
+            stmt_table = (f'CREATE SEQUENCE IF NOT EXISTS seq_{cls.name};\n'
+                          f'CREATE TABLE IF NOT EXISTS {cls.name} (\n   '
+                          f'{table_fields}\n);')
+        else:
+            stmt_table = (f'CREATE TABLE IF NOT EXISTS {cls.name} (\n   '
+                          f'{table_fields}\n);')
+        stmts_fk = [
+            f'ALTER TABLE {cls.name} ADD {constraint}'
+            for col in cls.constraints if col in columns_later
+            for constraint in col.sql_constraints()
+        ]
         return stmt_table, stmts_fk
 
     @classmethod
@@ -205,8 +215,10 @@ class AssociationTable(Table):
     @classmethod
     def sql_constraints(cls):
         """Returns the constraints for classes derived from AssociationTable."""
-        return ("UNIQUE "
-                f"({', '.join(rel.lfkey for rel in cls.local_relationships)})")
+        return [
+            "UNIQUE "
+            f"({', '.join(rel.lfkey for rel in cls.local_relationships)})"
+        ]
 
 
 def parse_model():
