@@ -208,10 +208,10 @@ class Collection(Resource):
             if document.id_number:
                 return await self.post_with_id(document, query)
             return await self.post_without_id(document, query)
-        except UniqueViolationError:
+        except UniqueViolationError as exc:
             raise ErrorsException([
                 DocumentDataDuplicateIdError(f"/data/id/{document.data['id']}")
-            ])
+            ]) from exc
 
     async def post_with_id(self, document, query):
         """Produces the response for a POST /{collection} request where the
@@ -269,9 +269,9 @@ class Collection(Resource):
                     await env.connection.execute(stmt, env.id_number,
                                                  *env.attributes.values(),
                                                  *lfkey_values)
-        except ForeignKeyViolationError:
+        except ForeignKeyViolationError as exc:
             env.cancel()
-            raise NonexistentRelationshipIdError()
+            raise NonexistentRelationshipIdError() from exc
 
     async def post_without_id_task(self, env):
         """Updates the database collection table based on the POST
@@ -302,9 +302,9 @@ class Collection(Resource):
                     env.id_number = await env.connection.fetchval(
                         stmt, *env.attributes.values(), *lfkey_values)
                     env.event.set()
-        except ForeignKeyViolationError:
+        except ForeignKeyViolationError as exc:
             env.cancel()
-            raise NonexistentRelationshipIdError()
+            raise NonexistentRelationshipIdError() from exc
 
     async def to_document(self, query=None, links=None):
         """Creates the document for the resource objects in this resource
@@ -754,5 +754,6 @@ def parse_collection(request):
     collection_name = request.match_info['collection']
     try:
         return Collection.by_name[collection_name]
-    except KeyError:
-        raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')])
+    except KeyError as exc:
+        raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')
+                              ]) from exc
