@@ -25,6 +25,7 @@ from itertools import chain
 
 from asyncpg.exceptions import ForeignKeyViolationError
 
+from ajsonapi.conversions import id_number_to_name
 from ajsonapi.document import ResourceObjectDocument
 from ajsonapi.environments import GetObjectIncludedEnvironment
 from ajsonapi.errors import (
@@ -90,17 +91,14 @@ class Object(Resource):
             async with self.table.pool.acquire() as connection:
                 log.debug(f'{stmt}: {self.id.number}')
                 result = await connection.execute(stmt, self.id.number)
-        except ForeignKeyViolationError:
+        except ForeignKeyViolationError as exc:
             raise ErrorsException(
-                [DeleteObjectRemotelyRelatedError(self.path())])
+                [DeleteObjectRemotelyRelatedError(self.path())]) from exc
         if result == 'DELETE 0':
             raise ErrorsException([ResourceNotFoundError(self.path())])
         event = DeleteEvent({
             'type': self.collection.name,
-            'id': str(self.id.number),
-            'links': {
-                'self': f'/{self.collection.name}/{self.id.number}'
-            },
+            'id': id_number_to_name(self.id.number),
         })
         await event.broadcast()
         return no_data_response()
@@ -148,9 +146,9 @@ class Object(Resource):
             if result == 'UPDATE 0':
                 env.cancel()
                 raise ErrorsException([ResourceNotFoundError(self.path())])
-        except ForeignKeyViolationError:
+        except ForeignKeyViolationError as exc:
             env.cancel()
-            raise NonexistentRelationshipIdError()
+            raise NonexistentRelationshipIdError() from exc
 
     async def to_document(self, query=None, links=None):
         """Creates the document for this resource object.
@@ -440,13 +438,15 @@ def parse(request):
 
     try:
         collection = Collection.by_name[collection_name]
-    except KeyError:
-        raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')])
+    except KeyError as exc:
+        raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')
+                              ]) from exc
 
     try:
         id_ = IdValue(id_name)
-    except ValueError:
-        raise ErrorsException(
-            [ResourceNotFoundMalformedIdError(f'/{collection_name}/{id_name}')])
+    except ValueError as exc:
+        raise ErrorsException([
+            ResourceNotFoundMalformedIdError(f'/{collection_name}/{id_name}')
+        ]) from exc
 
     return Object(collection, id_)
