@@ -283,11 +283,13 @@ class OneToOneLocalRelationship(ToOneRelationship):
                     ResourceNotFoundError(
                         f'/{self.collection.name}/{self.id.name}')
                 ])
-        except UniqueViolationError:
-            raise ErrorsException([DocumentDataRelationshipConflictError()])
-        except ForeignKeyViolationError:
-            raise ErrorsException(
-                [DocumentDataNonexistentIdError(f'/data/id/{data_id.name}')])
+        except UniqueViolationError as exc:
+            raise ErrorsException([DocumentDataRelationshipConflictError()
+                                  ]) from exc
+        except ForeignKeyViolationError as exc:
+            raise ErrorsException([
+                DocumentDataNonexistentIdError(f'/data/id/{data_id.name}')
+            ]) from exc
 
 
 class OneToOneRemoteRelationship(ToOneRelationship):
@@ -347,11 +349,11 @@ class OneToOneRemoteRelationship(ToOneRelationship):
                                 ])
                             raise ErrorsException(
                                 [DocumentDataRelationshipConflictError()])
-                    except ForeignKeyViolationError:
+                    except ForeignKeyViolationError as exc:
                         raise ErrorsException([
                             ResourceNotFoundError(
                                 f'/{self.collection.name}/{self.id.name}')
-                        ])
+                        ]) from exc
 
 
 class ManyToOneRelationship(ToOneRelationship):
@@ -397,9 +399,10 @@ class ManyToOneRelationship(ToOneRelationship):
                     ResourceNotFoundError(
                         f'/{self.collection.name}/{self.id.name}')
                 ])
-        except ForeignKeyViolationError:
-            raise ErrorsException(
-                [DocumentDataNonexistentIdError(f'/data/id/{data_id.name}')])
+        except ForeignKeyViolationError as exc:
+            raise ErrorsException([
+                DocumentDataNonexistentIdError(f'/data/id/{data_id.name}')
+            ]) from exc
 
 
 class ToManyRelationship(Relationship):
@@ -532,11 +535,11 @@ class OneToManyRelationship(ToManyRelationship):
                                 if data_id.number not in records_set
                             ]
                             raise ErrorsException(errors)
-                    except ForeignKeyViolationError:
+                    except ForeignKeyViolationError as exc:
                         raise ErrorsException([
                             ResourceNotFoundError(
                                 f'/{self.collection.name}/{self.id.name}')
-                        ])
+                        ]) from exc
                 else:
                     await self.verify_id_exists(connection)
 
@@ -553,11 +556,11 @@ class OneToManyRelationship(ToManyRelationship):
                                   f'{data_id_numbers}')
                         result = await connection.execute(
                             stmt, self.id.number, data_id_numbers)
-                    except ForeignKeyViolationError:
+                    except ForeignKeyViolationError as exc:
                         raise ErrorsException([
                             ResourceNotFoundError(
                                 f'/{self.collection.name}/{self.id.name}')
-                        ])
+                        ]) from exc
                     if result != f'UPDATE {len(data_ids)}':
                         stmt_verify = (f'SELECT id '
                                        f'FROM {self.relationship.rtable.name} '
@@ -828,22 +831,24 @@ def make_relationship(collection_name, id_name, relationship_name):
 
     try:
         collection = Collection.by_name[collection_name]
-    except KeyError:
-        raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')])
+    except KeyError as exc:
+        raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')
+                              ]) from exc
 
     try:
         id_ = IdValue(id_name)
-    except ValueError:
-        raise ErrorsException(
-            [ResourceNotFoundMalformedIdError(f'/{collection_name}/{id_name}')])
+    except ValueError as exc:
+        raise ErrorsException([
+            ResourceNotFoundMalformedIdError(f'/{collection_name}/{id_name}')
+        ]) from exc
 
     try:
         relationship = getattr(collection.table.___, relationship_name)
-    except AttributeError:
+    except AttributeError as exc:
         raise ErrorsException([
             ResourceNotFoundError(f'/{collection_name}/{id_name}/'
                                   f'relationships/{relationship_name}')
-        ])
+        ]) from exc
 
     return relationship.make_uri_relationship(collection, id_)
 
